@@ -1,9 +1,17 @@
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The preferences manager. """
 
 
 # Enthought library imports.
-from traits.api import HasTraits, Instance, List, Property, \
-    Any, Bool, Dict
+from traits.api import HasTraits, Instance, List, Property, Bool
 from traitsui.api import Handler, HSplit, Item, TreeEditor
 from traitsui.api import TreeNode, View, HTMLEditor
 from traitsui.menu import Action
@@ -12,31 +20,26 @@ from traitsui.menu import Action
 from .preferences_node import PreferencesNode
 from .preferences_page import PreferencesPage
 
-# fixme: This is part of the attempt to allow developers to use non-Traits UI
-# preferences pages. It doesn't work yet!
-##from widget_editor import WidgetEditor
-
 
 # A tree editor for preferences nodes.
 tree_editor = TreeEditor(
-    nodes = [
+    nodes=[
         TreeNode(
-            node_for  = [PreferencesNode],
-            auto_open = False,
-            children  = 'children',
-            label     = 'name',
-            rename    = False,
-            copy      = False,
-            delete    = False,
-            insert    = False,
-            menu      = None,
+            node_for=[PreferencesNode],
+            auto_open=False,
+            children="children",
+            label="name",
+            rename=False,
+            copy=False,
+            delete=False,
+            insert=False,
+            menu=None,
         ),
     ],
-
-    editable   = False,
-    hide_root  = True,
-    selected   = 'selected_node',
-    show_icons = False
+    editable=False,
+    hide_root=True,
+    selected="selected_node",
+    show_icons=False,
 )
 
 
@@ -46,22 +49,21 @@ class PreferencesHelpWindow(HasTraits):
     def traits_view(self):
         """ Default view to show for this class. """
         args = []
-        kw_args = {'title' : 'Preferences Page Help',
-                   'buttons' : ['OK'],
-                   'width' : 800,
-                   'height' : 800,
-                   'resizable' : True,
-                   'id' : 'apptools.preferences.ui.preferences_manager.help'}
+        kw_args = {
+            "title": "Preferences Page Help",
+            "buttons": ["OK"],
+            "width": 800,
+            "height": 800,
+            "resizable": True,
+            "id": "apptools.preferences.ui.preferences_manager.help",
+        }
         to_show = {}
 
         for name, trait_obj in self.traits().items():
-            if name != 'trait_added' and name != 'trait_modified':
+            if name != "trait_added" and name != "trait_modified":
                 to_show[name] = trait_obj.help
         for name in to_show:
-                args.append(Item(name,
-                                 style='readonly',
-                                 editor=HTMLEditor()
-                                 ))
+            args.append(Item(name, style="readonly", editor=HTMLEditor()))
 
         view = View(*args, **kw_args)
         return view
@@ -80,7 +82,6 @@ class PreferencesManagerHandler(Handler):
         """ Handle the **Apply** button being clicked. """
 
         info.object.apply()
-        return
 
     def init(self, info):
         """ Initialize the controls of a user interface. """
@@ -90,7 +91,6 @@ class PreferencesManagerHandler(Handler):
 
         return super(PreferencesManagerHandler, self).init(info)
 
-
     def close(self, info, is_ok):
         """ Close a dialog-based user interface. """
 
@@ -99,19 +99,16 @@ class PreferencesManagerHandler(Handler):
 
         return super(PreferencesManagerHandler, self).close(info, is_ok)
 
-
     def preferences_help(self, info):
         """ Custom preferences help panel. The Traits help doesn't work."""
         current_page = self.model.selected_page
         to_show = {}
         for trait_name, trait_obj in current_page.traits().items():
-            if hasattr(trait_obj, 'show_help') and trait_obj.show_help:
+            if hasattr(trait_obj, "show_help") and trait_obj.show_help:
                 to_show[trait_name] = trait_obj.help
 
         help_obj = PreferencesHelpWindow(**to_show)
-        help_obj.edit_traits(kind='livemodal')
-        return
-
+        help_obj.edit_traits(kind="livemodal")
 
     ###########################################################################
     # Private interface.
@@ -126,8 +123,6 @@ class PreferencesManagerHandler(Handler):
             node = root.children[0]
             info.object.selected_page = node.page
 
-        return
-
 
 class PreferencesManager(HasTraits):
     """ The preferences manager. """
@@ -158,63 +153,60 @@ class PreferencesManager(HasTraits):
     def traits_view(self):
         """ Default traits view for this class. """
 
-        help_action = Action(name = 'Info', action = 'preferences_help')
+        help_action = Action(name="Info", action="preferences_help")
 
-        buttons = ['OK', 'Cancel']
+        buttons = ["OK", "Cancel"]
 
         if self.show_apply:
-            buttons = ['Apply'] + buttons
+            buttons = ["Apply"] + buttons
         if self.show_help:
             buttons = [help_action] + buttons
 
-
         # A tree editor for preferences nodes.
         tree_editor = TreeEditor(
-            nodes = [
+            nodes=[
                 TreeNode(
-                    node_for  = [PreferencesNode],
-                    auto_open = False,
-                    children  = 'children',
-                    label     = 'name',
-                    rename    = False,
-                    copy      = False,
-                    delete    = False,
-                    insert    = False,
-                    menu      = None,
+                    node_for=[PreferencesNode],
+                    auto_open=False,
+                    children="children",
+                    label="name",
+                    rename=False,
+                    copy=False,
+                    delete=False,
+                    insert=False,
+                    menu=None,
                 ),
             ],
-            on_select  = self._selection_changed,
-            editable   = False,
-            hide_root  = True,
-            selected   = 'selected_node',
-            show_icons = False
+            on_select=self._selection_changed,
+            editable=False,
+            hide_root=True,
+            selected="selected_node",
+            show_icons=False,
         )
 
         view = View(
             HSplit(
                 Item(
-                    name       = 'root',
-                    editor     = tree_editor,
-                    show_label = False,
-                    width      = 250,
+                    name="root",
+                    editor=tree_editor,
+                    show_label=False,
+                    width=250,
                 ),
-
                 Item(
-                    name       = 'selected_page',
-                    #editor     = WidgetEditor(),
-                    show_label = False,
-                    width      = 450,
-                    style      = 'custom',
+                    name="selected_page",
+                    # editor     = WidgetEditor(),
+                    show_label=False,
+                    width=450,
+                    style="custom",
                 ),
             ),
-
-            buttons   = buttons,
-            handler   = PreferencesManagerHandler(model=self),
-            resizable = True,
-            title     = 'Preferences',
-            width     = .3,
-            height    = .3,
-            kind      = 'modal'
+            buttons=buttons,
+            handler=PreferencesManagerHandler(model=self),
+            resizable=True,
+            title="Preferences",
+            width=0.3,
+            height=0.3,
+            kind="modal",
         )
         self.selected_page = self.pages[0]
         return view
@@ -239,7 +231,7 @@ class PreferencesManager(HasTraits):
                 len_a = 0
 
             else:
-                len_a = len(a.category.split('/'))
+                len_a = len(a.category.split("/"))
 
             return len_a
 
@@ -250,8 +242,8 @@ class PreferencesManager(HasTraits):
         #
         # fixme: Currently we have to create a dummy page for the root node
         # event though the root does not get shown in the tree!
-        root_page = PreferencesPage(name='Root', preferences_path='root')
-        root      = PreferencesNode(page=root_page)
+        root_page = PreferencesPage(name="Root", preferences_path="root")
+        root = PreferencesNode(page=root_page)
 
         for page in self.pages:
             # Get the page's parent node.
@@ -267,14 +259,11 @@ class PreferencesManager(HasTraits):
     def _selection_changed(self, new_selection):
         self.selected_node = new_selection
 
-
     def _selected_node_changed(self, new):
         """ Static trait change handler. """
         if self.selected_node:
             self.selected_page = self.selected_node.page
 
-        return
-
     #### Methods ##############################################################
 
     def apply(self):
@@ -283,8 +272,6 @@ class PreferencesManager(HasTraits):
         for page in self.pages:
             page.apply()
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -295,10 +282,8 @@ class PreferencesManager(HasTraits):
         parent = root
 
         if len(page.category) > 0:
-            components = page.category.split('/')
+            components = page.category.split("/")
             for component in components:
                 parent = parent.lookup(component)
 
         return parent
-
-#### EOF ######################################################################
