@@ -1,22 +1,28 @@
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """Simple utility functions provided by the scripting API.
 """
-# Author: Prabhu Ramachandran <prabhu [at] aero . iitb . ac . in>
-# Copyright (c) 2008,  Prabhu Ramachandran
-# License: BSD Style.
 
-from recorder import Recorder
-from recorder_with_ui import RecorderWithUI
-from package_globals import get_recorder, set_recorder
+from .recorder import Recorder
+from .recorder_with_ui import RecorderWithUI
+from .package_globals import get_recorder, set_recorder
 
 
-################################################################################
+###############################################################################
 # Utility functions.
-################################################################################
+###############################################################################
 def start_recording(object, ui=True, **kw):
     """Convenience function to start recording.  Returns the recorder.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
 
     object :  object to record.
 
@@ -27,7 +33,7 @@ def start_recording(object, ui=True, **kw):
     """
     if ui:
         r = RecorderWithUI(root=object)
-        r.edit_traits(kind='live')
+        r.edit_traits(kind="live")
     else:
         r = Recorder()
     # Set the global recorder.
@@ -36,6 +42,7 @@ def start_recording(object, ui=True, **kw):
     r.register(object, **kw)
     return r
 
+
 def stop_recording(object, save=True):
     """Stop recording the object.  If `save` is `True`, this will pop up
     a UI to ask where to save the script.
@@ -48,4 +55,3 @@ def stop_recording(object, save=True):
     # Save the script.
     if save:
         recorder.ui_save()
-
