@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -10,8 +10,17 @@
 #
 # Author: Riverbank Computing Limited
 # Description: <Enthought undo package component>
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
-from command_action import CommandAction
-from redo_action import RedoAction
-from undo_action import UndoAction
+""" API for apptools.undo.action subpackage.
+
+- :class:`~.CommandAction`
+- :class:`~.RedoAction`
+- :class:`~.UndoAction`
+"""
+
+from pyface.undo.action.api import (
+    CommandAction,
+    RedoAction,
+    UndoAction,
+)
